<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>



-------------------------------------------------------------------------------

## 📚简介

pofile是python自动化办公之**批量处理文件/文件夹**的代码合集。

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ pofile -U
```

-------------------------------------------------------------------------------

## 📝功能

| 方法名            | 功能               | 视频（文档）                                              | 演示代码                                                    |
| ----------------- | ------------------ | --------------------------------------------------------- | ----------------------------------------------------------- |
| replace4filename  | 批量重命名         | [视频](https://www.bilibili.com/video/BV12r4y187Yj)       | [源码](https://github.com/CoderWanFeng/python-office/blob/master/demo/pofile/%E6%89%B9%E9%87%8F%E9%87%8D%E5%91%BD%E5%90%8D.py)   |
| search_by_content | 根据内容，查找文件 | [视频](https://www.bilibili.com/video/BV13P411n77G)       | [源码](https://github.com/CoderWanFeng/python-office/blob/master/demo/pofile/%E6%A0%B9%E6%8D%AE%E5%86%85%E5%AE%B9%EF%BC%8C%E6%9F%A5%E6%89%BE%E6%96%87%E4%BB%B6.py)   |
| group_by_name     | 自动整理文件         | [文档](https://mp.weixin.qq.com/s/AVFttFz-IjZD1Ra3K-580A) | [源码](https://github.com/CoderWanFeng/python-office/blob/master/demo/pofile/%E8%87%AA%E5%8A%A8%E6%95%B4%E7%90%86%E6%96%87%E4%BB%B6%E5%A4%B9.py)   |
| get_files         | 获取文件列表         | [视频](https://www.bilibili.com/video/BV1ua4y1M7ya)       | [源码](https://github.com/CoderWanFeng/python-office/blob/master/demo/pofile/%E6%89%B9%E9%87%8F%E8%8E%B7%E5%8F%96%E6%96%87%E4%BB%B6%E5%88%97%E8%A1%A8.py) |
| mkdir             | 新建文件夹         | [视频](https://www.bilibili.com/video/BV1ua4y1M7ya)       | [源码](https://github.com/CoderWanFeng/python-office/blob/master/demo/pofile/%E6%96%B0%E5%BB%BA%E6%96%87%E4%BB%B6%E5%A4%B9.py) |
#### 相关资料：

- [📘官网：https://www.python-office.com/](https://www.python-office.com/)
- https://github.com/CoderWanFeng/pocode
## 🏗️添砖加瓦

### 📐PR的建议

python-office欢迎任何人来添砖加瓦，贡献代码，建议提交的pr（pull request）符合一些规范，规范如下：

参与项目建设的步骤：

- 例如：你需要给python-office添加一个add方法。
    1. 你的Github账户名为：demo
    2. 于是你在./contributors新建了文件夹./demo
    3. 新建了add.py文件，编辑你的代码
    4. 编辑完成，提交pr到master分支（gitee或者GitHub，都可以）。可以注明你对自己功能的取名建议
    5. 晚枫收到后，会对各位的代码进行测试后，合并后打包上传到python官方库

### 📐代码规范

1. 注释完备，尤其每个新增的方法应按照Google Python文档规范标明方法说明、参数说明、返回值说明等信息，必要时请添加单元测试，如果愿意，也可以加上你的大名。
2. python-office的文档，需要进行格式化。注意：只能格式化你自己的代码
3. 请直接pull request到`master`分支。`master`是主分支，表示已经发布pypi库的版本。**未来参与人数增多，会开辟新的分支，请留意本文档的更新。
   **
4. 我们如果关闭了你的issue或pr，请不要诧异，这是我们保持问题处理整洁的一种方式，你依旧可以继续讨论，当有讨论结果时我们会重新打开。

### 🧬贡献代码的步骤

1. 在Gitee或者Github上fork项目到自己的repo
2. 把fork过去的项目也就是你的项目clone到你的本地
3. 修改代码
4. commit后push到自己的库
5. 登录Gitee或Github在你首页可以看到一个 pull request 按钮，点击它，填写一些说明信息，然后提交到master分支即可。
6. 等待维护者合并

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和python-office代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/pofile/issues)

-------------------------------------------------------------------------------

## 📌联系作者

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>